@@ -6,10 +6,9 @@
 
 import numpy
 
-import CGNS.PAT.cgnserrors as CE
-import CGNS.PAT.cgnskeywords as CK
-import CGNS.PAT.cgnsutils as CU
-
+from . import cgnserrors as CE
+from . import cgnskeywords as CK
+from . import cgnsutils as CU
 
 # =============================================================================
 # MLL-like calls
